@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "shx" "1.5.2"
+(define-package "shx" "20251225.43"
   "Extras for the comint-mode shell."
   '((emacs "24.4"))
   :url "https://github.com/riscy/shx-for-emacs"
